@@ -109,12 +109,14 @@ Permutations <- R6::R6Class(
         v = NULL,
         freq = NULL,
         replace = NULL,
-        initialize = function(n, k, v = NULL, freq = NULL, replace = FALSE) {
+        skip = NULL,
+        initialize = function(n, k, v = NULL, freq = NULL, replace = FALSE, skip = NULL) {
             self$n <- as.integer(n)
             self$k <- as.integer(k)
             self$v <- v
             self$freq <- freq
             self$replace <- replace
+            self$skip <- skip
             self$reset()
         },
         reset = function() {
@@ -133,7 +135,7 @@ Permutations <- R6::R6Class(
             } else {
                 out <- .Call("get_permutations", PACKAGE = "arrangements",
                              NULL, self$k, self$n, self$v, self$freq, self$replace, layout,
-                             d, NULL, NULL, private$state, NULL, drop)
+                             d, NULL, NULL, private$state, self$skip, drop)
                 is.null(out) && self$reset()
             }
             out
@@ -157,6 +159,7 @@ Permutations <- R6::R6Class(
 #' permutation(s) via the `getnext()` method.
 #'
 #' @template param_pc
+#' @param skip the number of combinations skipped
 #' @seealso [permutations] for generating all permutations and [npermutations] to calculate number of permutations
 #' @examples
 #' iperm <- ipermutations(5, 2)
@@ -171,7 +174,7 @@ Permutations <- R6::R6Class(
 #'   sum(x)
 #' }
 #' @export
-ipermutations <- function(x, k = n, n = NULL, v = NULL, freq = NULL, replace = FALSE) {
+ipermutations <- function(x, k = n, n = NULL, v = NULL, freq = NULL, replace = FALSE, skip = NULL) {
     if (missing(x)) {
         n <- validate_n_value(n, v, freq, replace)
     } else {
@@ -184,5 +187,5 @@ ipermutations <- function(x, k = n, n = NULL, v = NULL, freq = NULL, replace = F
     }
     (k %% 1 == 0 && k >= 0) || stop("expect integer")
 
-    Permutations$new(n, k, v, freq, replace)
+    Permutations$new(n, k, v, freq, replace, skip)
 }
